<?php
/**
 * Implement Custom Header functionality for Big Stone
 *
 * @package Big Stone
 * @since Big Stone 1.0
 */

/**
 * Set up the WordPress core custom header settings.
 *
 * @since Big Stone 1.0
 *
 * @uses big_stone_header_style()
 * @uses big_stone_admin_header_style()
 * @uses big_stone_admin_header_image()
 */
function big_stone_custom_header_setup() {
	/**
	 * Filter Big Stone custom-header support arguments.
	 *
	 * @since Big Stone 1.0
	 *
	 * @param array $args {
	 *     An array of custom-header support arguments.
	 *
	 *     @type bool   $header_text            Whether to display custom header text. Default false.
	 *     @type int    $width                  Width in pixels of the custom header image. Default 1260.
	 *     @type int    $height                 Height in pixels of the custom header image. Default 240.
	 *     @type bool   $flex_height            Whether to allow flexible-height header images. Default true.
	 *     @type string $admin_head_callback    Callback function used to style the image displayed in
	 *                                          the Appearance > Header screen.
	 *     @type string $admin_preview_callback Callback function used to create the custom header markup in
	 *                                          the Appearance > Header screen.
	 * }
	 */
	add_theme_support( 'custom-header', apply_filters( 'big_stone_custom_header_args', array(
		'default-text-color'     => '10222B',
		'width'                  => 1260,
		'height'                 => 240,
		'flex-height'            => true,
		'wp-head-callback'       => 'big_stone_header_style',
		'admin-head-callback'    => 'big_stone_admin_header_style',
		'admin-preview-callback' => 'big_stone_admin_header_image',
	) ) );
}
add_action( 'after_setup_theme', 'big_stone_custom_header_setup' );

if ( ! function_exists( 'big_stone_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @see big_stone_custom_header_setup().
 *
 */
function big_stone_header_style() {
	$text_color = get_header_textcolor();

	// If no custom color for text is set, let's bail.
	if ( display_header_text() && $text_color === get_theme_support( 'custom-header', 'default-text-color' ) )
		return;

	// If we get this far, we have custom styles.
	?>
	<style type="text/css" id="big_stone-header-css">
	<?php
		// Has the text been hidden?
		if ( ! display_header_text() ) :
	?>
		.site-title,
		.site-description {
			clip: rect(1px 1px 1px 1px); /* IE7 */
			clip: rect(1px, 1px, 1px, 1px);
			position: absolute;
		}
	<?php
		// If the user has set a custom color for the text, use that.
		elseif ( $text_color != get_theme_support( 'custom-header', 'default-text-color' ) ) :
	?>
		.site-title a {
			color: #<?php echo esc_attr( $text_color ); ?>;
		}
	<?php endif; ?>
	</style>
	<?php
}
endif; // big_stone_header_style


if ( ! function_exists( 'big_stone_admin_header_style' ) ) :
/**
 * Style the header image displayed on the Appearance > Header screen.
 *
 * @see big_stone_custom_header_setup()
 *
 * @since Big Stone 1.0
 */
function big_stone_admin_header_style() {
?>
	<style type="text/css" id="big_stone-admin-header-css">
	.appearance_page_custom-header #headimg {
		background: #BDD684;
        border: none;
        min-height: 0 !important
	}
	#headimg h1 {
		font-size: 45px;
        font-family: Georgia, 'Times New Roman', serif;
        font-style: italic;
        font-weight: normal;
        padding: 0.8em 0.5em 0;
		margin: 0 auto;
	}
    #headimg h1 a{
        color: #10222B;
        text-decoration: none;
    }
	#desc { /* This is the site description (tagline) displayed in the preview */
        padding: 0 1.7em 2em;
		font-size: 20px;
        color: #F6FFE0;
        text-decoration: none;
    }
	</style>
<?php
}
endif; // big_stone_admin_header_style

if ( ! function_exists( 'big_stone_admin_header_image' ) ) :
/**
 * Create the custom header image markup displayed on the Appearance > Header screen.
 *
 * @see big_stone_custom_header_setup()
 *
 * @since Big Stone 1.0
 */
function big_stone_admin_header_image() {
?>
	<div id="headimg">
		<h1 class="displaying-header-text"><a id="name"<?php echo sprintf( ' style="color:#%s;"', get_header_textcolor() ); ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
		<div id="desc"><?php bloginfo( 'description' ); ?></div>
		<?php if ( get_header_image() ) : ?>
		<img src="<?php header_image(); ?>" alt="">
		<?php endif; ?>
	</div>
<?php
}
endif; // big_stone_admin_header_image